==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/common/commondefs.h <==
#ifndef COMMONDEFS_H
#define COMMONDEFS_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <qstring.h>
#include <qstringlist.h>
#include <qpixmap.h>
#include <qiconset.h>
#include <kicontheme.h>

class GUI
{
	public:

		static QPixmap customIcon( const QString& name, int group, int size=KIcon::SizeMedium, int state=KIcon::DefaultState );
		static QIconSet customIconSet( const QString& name, int group, int size=KIcon::SizeMedium );
};

class String
{
	public:

		static QString title( const QString& text );
		static QString capitalize( const QString& text );
		static QString sentence( const QString& text );

	protected:

		static int rfindFunctionStart( const QString& text );
		static int rfindFunctionEnd( const QString& text, int startPos );
};

class System
{
	public:

		// FALSE ON ERROR
		static bool copy( const QString& srcPath, const QString& dstPath );
		static bool move( const QString& srcPath, const QString& dstPath );
		static bool remove( const QString& path );
		static bool recursiveMakeDir( const QString& path, QStringList* createdDirsList=0 );

		static bool isReadable( const QString& path );
		static bool isWritable( const QString& path );

		static QString user();
		static QString homeDir();
		static QString tempDir();

		static QString newFile( const QString& dirPath=tempDir(), const QString& fileName="tempfile", const QString& extension="" );
};

#endif

==> subtitlecomposer-0.4.2.tar.bz2: subtitlecomposer-0.4.2/src/common/commondefs.h <==
#ifndef COMMONDEFS_H
#define COMMONDEFS_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <qstring.h>
#include <qstringlist.h>
#include <qpixmap.h>
#include <qiconset.h>

#include <kurl.h>
#include <kiconloader.h>

class GUI
{
	public:

		static QPixmap customIcon( const QString& name, int group, int size=KIcon::SizeMedium, int state=KIcon::DefaultState );
		static QIconSet customIconSet( const QString& name, int group, int size=KIcon::SizeMedium );
};

class String
{
	public:

		static QString title( const QString& text );
		static QString capitalize( const QString& text );
		static QString sentence( const QString& text );

	protected:

		static int rfindFunctionStart( const QString& text );
		static int rfindFunctionEnd( const QString& text, int startPos );
};

class System
{
	public:

		// FALSE ON ERROR
		static bool copy( const QString& srcPath, const QString& dstPath );
		static bool move( const QString& srcPath, const QString& dstPath );
		static bool remove( const QString& path );
		static bool recursiveMakeDir( const QString& path, QStringList* createdDirsList=0 );

		static bool isReadable( const QString& path );
		static bool isWritable( const QString& path );

		static QString user();
		static QString homeDir();
		static QString tempDir();

		static KURL newURL( const KURL& baseURL, const QString& fileName="tempfile", const QString& extension="", int retries=10 );
};

#endif
